summaryrefslogtreecommitdiff
path: root/Master/setuptl/TLPM/help.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Master/setuptl/TLPM/help.pm')
-rw-r--r--Master/setuptl/TLPM/help.pm48
1 files changed, 25 insertions, 23 deletions
diff --git a/Master/setuptl/TLPM/help.pm b/Master/setuptl/TLPM/help.pm
index ec3b0a45b6e..b8dc62535a7 100644
--- a/Master/setuptl/TLPM/help.pm
+++ b/Master/setuptl/TLPM/help.pm
@@ -1,4 +1,4 @@
# This file belongs to TLPM v2.16, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# help
@@ -38,28 +38,30 @@ Public Domain, P.Jackowski\@gust.org.pl",
* About TLPM
TLPM (TeX Live Package Manager) helps to search, trace dependencies, and
-install TeX Live packages. It works with TeX Live 2004-2006. Initially, TLPM
-was just my private Perl script for controlling the mass of TeX Live packages
-repository. Since there were no win-installer on TeX Live 2004, TLPM became a
-rescue solution. Starting from version 2.11, TLPM works, with some
-restrictions, under Unix shells as well.
-
-Since there is no consistent versioning system withing TeX Live distribution,
-TLPM does NOT support upgrades or downgrades, neither of packages, nor of the
-entire distribution. TLPM fully relies on the information retrieved from the
-TPM files (actually from text files stored in the 'texmf/lists' directory).
-If you don't trust TPMs, do NOT trust TLPM either!
+install TeX Live packages. It works with TeX Live 2004, 2005, 2006/07
+editions. Initially, TLPM was just my private Perl script for controlling the
+mass of TeX Live packages repository. Since there were no win-installer on
+TeX Live 2004, TLPM became a rescue solution. Starting from version 2.11,
+TLPM works, with some restrictions, under Unix shells as well.
All the configuration is beyond the scope of TLPM functionality. TLPM doesn't
perform any post-installation actions such as setting of environment
variables, building formats or updating fontmap files. All those actions are
accomplished by a pretty nice TLPMGUI front-end written by Tomek \\{}Luczak.
+Since there is no (not yet) consistent versioning system within TeX Live
+distribution, TLPM does NOT support upgrades or downgrades, neither of
+packages, nor of the entire distribution. TLPM fully relies on the
+information retrieved from the TPM files (actually from text files stored in
+the 'texmf/lists' directory). If you don't trust TPMs, do NOT trust TLPM
+either!
+
* Usage
-TLPM tries to detect the CD/DVD drive with TeX Live disk automagically. If
-the magic fails, TLPM prompts to provide a mounting point, unless one use the
-'--source' command-line option or the 'tl_source' environment variable (which
-might be useful while installing from local hard drive resources).
+TLPM tries to detect the CD/DVD drive with TeX Live disk automagically (this
+heuristic is performed not performed on Unix shells). If the magic fails,
+TLPM prompts to provide a mounting point, unless one use the '--source'
+command-line option or the 'tl_source' environment variable, which might be
+useful while installing TeX Live from local hard drive resources.
The target installation directory can be specified with the '--directory'
command-line option or the 'tl_target' environment variable. If both are
@@ -82,7 +84,7 @@ TLPM is self documented -- 'help [<command>]' informs about usage details.
TLPM respects quotations (both double quotes and single quotes) used in command
line. Quotation is necessary while using path names with spaces (strongly not
recommended!) or other strange characters that may conflict with the command
-syntax. If so, please quote the entire phrase. Whenever analysing the command,
+syntax. If so, please quote the entire phrase. Whenever analyzing the command,
TLPM also resolves environment variables expressed as '%variable%' or '\$variable'.
To ensure possibly similar behaviour for different platforms, TLPM interprets
@@ -111,7 +113,7 @@ Bugs reports and comments are welcome (tlpmgui\@gust.org.pl)
30.09.2005, 1.04 -- tiny changes in CD detection routine
05.10.2005, 2.00 -- general rework; mostly in messaging system and installation;
now TLPM supports also TeX Live DVD (slooow...)
-06.10.2005, 2.01 -- again, changes in CD/DVD detction routine because of removing
+06.10.2005, 2.01 -- again, changes in CD/DVD detection routine because of removing
tlpm(gui) stuff from TL root directory
08.10.2005, 2.02 -- bugfix; while removing standalone packages, uninstall
routine was performed twice
@@ -122,7 +124,7 @@ Bugs reports and comments are welcome (tlpmgui\@gust.org.pl)
13.10.2005, 2.06 -- experimental progress info while installing from DVD
14.10.2005, 2.07 -- progress info while installing from CD and DVD
and --quiet option for 'inst' command
-25.10.2005, 2.08 -- give up to with hanging on DVD instalation under Win98;
+25.10.2005, 2.08 -- give up to with hanging on DVD installation under Win98;
just note added
26.10.2005, 2.09 -- yet another slight correction
27.10.2005, 2.10 -- Karl confirmed that 'texlive2005' directory
@@ -130,14 +132,15 @@ Bugs reports and comments are welcome (tlpmgui\@gust.org.pl)
19.03.2006, 2.11 -- some experimental rework; allows to extract binaries for other
platforms, can work under Linux, prompts for source drive
or mounting point unless found automatically
-23.04.2006, 2.12 -- addedd installation from DVD support for Linux; still slow,
+23.04.2006, 2.12 -- added installation from DVD support for Linux; still slow,
as in Windows
08.05.2006, 2.13 -- bugfix; changes 2.12 spoil installation from cd
04.06.2006, 2.14 -- code commented
-07.01.2007, 2.15 -- help update for TL2006
+07.01.2007, 2.15 -- help update for TeX Live 2006/07 edition
08.01.2007, 2.16 -- bugfix; typing 'version' command was causing a program crash;
there is no such a command available anymore; program version
is displayed in the banner and command prompt
+09.01.2007, 2.17 -- code comments, readme changes
* Known issues
1. Installation from DVD is much slower than from CD. Sorry...
@@ -162,8 +165,7 @@ Hardly reproducable...
tlpm [platforms] [-s \<source\>] [-d \<target\>] [-b \<batch\>]
DESCRIPTION:
-TLPM help searching for, installing and uninstalling TeX Live packages. It
-should be used in conjunction with the TeX Live 2004-2006 CD/DVD.
+TLPM help searching for, installing and uninstalling TeX Live packages.
COMMANDS:
list list packages or files with names matching the given phrase
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.16, TeX Live Package Manager
+# This file belongs to TLPM v2.17, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# help